@@ -99,6 +99,9 @@ SERVICE_CATALOG_CREATE_PORTFOLIO_SHARE_PER_REGION = (
 SERVICE_CATALOG_DESCRIBE_PORTFOLIO_SHARE_STATUS_PER_REGION = (
     "SERVICE_CATALOG_DESCRIBE_PORTFOLIO_SHARE_STATUS" + PER_REGION
 )
+SERVICE_CATALOG_DESCRIBE_PORTFOLIO_SHARES_PER_REGION = (
+    "SERVICE_CATALOG_DESCRIBE_PORTFOLIO_SHARES" + PER_REGION
+)
 SERVICE_CATALOG_CREATE_PORTFOLIO_SHARE_PER_REGION_OF_ACCOUNT = (
     "SERVICE_CATALOG_CREATE_PORTFOLIO_SHARE" + PER_REGION_OF_ACCOUNT
 )
@@ -480,6 +483,11 @@ def create(section_name, parameters_to_use, puppet_account_id):
             ORGANIZATIONS_CREATE_OU,
         ]
 
+    elif section_name == constants.DESCRIBE_PORTFOLIO_SHARES:
+        resources = [
+            SERVICE_CATALOG_DESCRIBE_PORTFOLIO_SHARES_PER_REGION,
+        ]
+
     else:
         raise Exception(f"Unknown section_name: {section_name}")
 
